/*-----------------------------------------------------------------------------
 * Name:    stdout_USART.c
 * Purpose: STDOUT USART Template
 * Rev.:    1.0.0
 *-----------------------------------------------------------------------------*/

/* Copyright (c) 2013 - 2016 ARM LIMITED

   All rights reserved.
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
   - Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
   - Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
   - Neither the name of ARM nor the names of its contributors may be used
     to endorse or promote products derived from this software without
     specific prior written permission.
   *
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL COPYRIGHT HOLDERS AND CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
   ---------------------------------------------------------------------------*/

#include "samg55.h"                     // Device header
#include "RTE_Components.h"             // Component selection


//-------- <<< Use Configuration Wizard in Context Menu >>> --------------------


// <h>STDOUT USART Interface

//   <o>Baudrate
#define USART_BAUDRATE          115200

// </h>

/* Define  Baudrate setting (BRGR) for USART */
#define BAUD(b) ((SystemCoreClock + 8*b)/(16*b))

#define BRGR_CD (((SystemCoreClock / USART_BAUDRATE) >> 4)                   )
#define BRGR_FP (((SystemCoreClock / USART_BAUDRATE) >> 1) -  (BRGR_CD << 3) )

/**
  Initialize stdout

  \return          0 on success, or -1 on error.
*/
int stdout_init (void) {

  SystemCoreClockUpdate();

#ifdef RTE_Compiler_IO_STDOUT_User
  PMC->PMC_WPMR = 0x504D4300;                    /* Disable write protect */
  PMC->PMC_PCER0 = (1u << ID_PIOA);              /* enable clock for PIOA */
  PMC->PMC_PCER0 = (1u << ID_FLEXCOM7);          /* enable FLEXCOM7 clock */
  PMC->PMC_WPMR = 0x504D4301;                    /* Enable write protect */

  /* Configure USART7 Pins (PA28 = TX, PA27 = RX). */
  PIOA->PIO_WPMR = 0x50494F00;                   /* Disable write protect */
  PIOA->PIO_IDR        =  (PIO_PA27B_RXD7 | PIO_PA28B_TXD7);
  PIOA->PIO_PUDR       =  (PIO_PA27B_RXD7 | PIO_PA28B_TXD7);
  PIOA->PIO_ABCDSR[0] |=  (PIO_PA27B_RXD7 | PIO_PA28B_TXD7);
  PIOA->PIO_ABCDSR[1] &= ~(PIO_PA27B_RXD7 | PIO_PA28B_TXD7);
  PIOA->PIO_PDR        =  (PIO_PA27B_RXD7 | PIO_PA28B_TXD7);
  PIOA->PIO_WPMR = 0x50494F01;                   /* Enable write protect */

  FLEXCOM7->FLEXCOM_MR = FLEXCOM_MR_OPMODE_USART;

  USART7->US_WPMR = 0x55534100;                  /* Disable write protect */
  USART7->US_CR   = (US_CR_RSTRX | US_CR_RSTTX) |
                    (US_CR_RXDIS | US_CR_TXDIS);
  USART7->US_IDR  = 0xFFFFFFFFu;
  USART7->US_MR   = US_MR_USART_MODE_NORMAL |    /* (USART) Normal */
                    US_MR_USCLKS_MCK        |    /* (USART) Clock */
                    US_MR_CHRL_8_BIT        |    /* (USART) Character Length: 8 bits */
                    US_MR_PAR_NO            |    /* (USART) No Parity */
                    US_MR_NBSTOP_1_BIT      |    /* (USART) 1 stop bit */
                    US_MR_CHMODE_NORMAL      ;   /* (USART) Normal Mode */
  USART7->US_BRGR = US_BRGR_FP(BRGR_FP) | US_BRGR_CD(BRGR_CD);
  USART7->US_PTCR = US_PTCR_RXTDIS | US_PTCR_TXTDIS;
  USART7->US_CR   = US_CR_RXEN     | US_CR_TXEN;
  USART7->US_WPMR = 0x55534101;                  /* Enable write protect */

#endif
  return (0);
}


/**
  Put a character to the stdout

  \param[in]   ch  Character to output
  \return          The character written, or -1 on write error.
*/
int stdout_putchar (int ch) {

#ifdef RTE_Compiler_IO_STDOUT_User
  while ((USART7->US_CSR & US_CSR_TXEMPTY) == 0);
  USART7->US_THR = ch;
#endif
  return (ch);
}
